@@ -561,37 +561,7 @@
             }
             else{
                 ## right censored not clustered
-                fit <- .C("prodlimSRC",
-                          as.double(response[,"time"]),
-                          as.double(response[,"status"]),
-                          integer(0),
-                          as.double(entrytime),
-                          as.double(caseweights),
-                          integer(0),
-                          as.integer(N),
-                          integer(0),
-                          integer(0),
-                          as.integer(NU),
-                          as.integer(size.strata),
-                          time=double(N),
-                          nrisk=double(N),
-                          nevent=double(N),
-                          ncens=double(N),
-                          surv=double(N),
-                          double(0),
-                          hazard = double(N),
-                          var.hazard=double(N),
-                          extra.double=double(0),
-                          max.nc=integer(0),
-                          ntimes=integer(1),
-                          ntimes.strata=integer(NU),
-                          first.strata=integer(NU),
-                          as.integer(reverse),
-                          model=as.integer(0),
-                          independent=as.integer(1),
-                          delayed=as.integer(delayed),
-                          weighted=as.integer(weighted),
-                          PACKAGE="prodlim")
+                fit <- .C("prodlimSRC",as.double(response[,"time"]),as.double(response[,"status"]),integer(0),as.double(entrytime),as.double(caseweights),integer(0),as.integer(N),integer(0),integer(0),as.integer(NU),as.integer(size.strata),time=double(N),nrisk=double(N),nevent=double(N),ncens=double(N),surv=double(N),double(0),hazard = double(N),var.hazard=double(N),extra.double=double(0),max.nc=integer(0),ntimes=integer(1),ntimes.strata=integer(NU),first.strata=integer(NU),as.integer(reverse),model=as.integer(0),independent=as.integer(1),delayed=as.integer(delayed),weighted=as.integer(weighted),PACKAGE="prodlim")
                 NT <- fit$ntimes
                 Cout <- list("time"=fit$time[1:NT],
                              "n.risk"=fit$nrisk[1:NT],
